@@ -144,6 +144,14 @@ class ParserTest(TestCase):
         assert date.format == '%%%M!(|)', date.format
         assert str(date) == '%59!(|)', str(date)
 
+    # see RFC 5280 - problems are (1) 2 year -> 4 year conversion (2) Z as UTC
+    # def test_zulu(self):
+    #     date = SimpleDate('130706062100Z', format=invert('ymdHMSZ'), debug=True)
+    #     assert str(date) == '', str(date)
+
+    def test_asn1(self):
+        date = SimpleDate('May 25 23:59:59 2012 GMT')
+        assert str(date) == 'May 25 23:59:59 2012 GMT', str(date)
 
 class TZFactoryTest(TestCase):
 
